==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_de_DE.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de_DE">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>Der Check ist nahezu beendet; Vielen Dank für Ihre Geduld</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Vorbereiten</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Einige Fehler überprüft</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Zum Schreibtisch wechseln</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Willkommen, das System wurde erfolgreich upgedatet</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Aktuelle Version:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation>Logs ansehen</translation>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>Aktualisierungen erfolgreich</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Ihr Computer wird gleich neustarten %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Ihr Computer wird gleich ausgeschalten %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation>Logs ausblenden</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Aktualisierung fehlgeschlagen</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>BackUp fehlgeschlagen</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>System-Sicherung konnte nicht durchgeführt werden. Falls Sie mit den System-Aktualisierungen fortfahren, können Sie nicht wieder zurück zum alten System.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Zu geringer Speicherplatz. Bitte schaffen Sie Platz auf ihrer Festplatte und versuchen es erneut.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Keine Verbindung zum BackUp-Server. Bitte checken und erneut versuchen.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Keine Verbindung zum Aktualisierungs-Server. Bitte prüfen und erneut versuchen.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Abhängigkeiten-Fehler</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG-Fehler</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Erneut BackUp erstellen</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Mit Aktualisieren fortfahren</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Neustart</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Runterfahren</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>zum Schreibtisch wechseln</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Aktualisieren vorbereiten…</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Während der Installation der Aktualisierungen nicht Herunterfahren oder Ausschalten erzwingen. Anderenfalls kann ihr System Schaden nehmen.</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.19.tar.xz: BUILD/src/dde-update/translations/dde-update_de_DE.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de_DE">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>Der Check ist nahezu beendet; Vielen Dank für Ihre Geduld</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Vorbereiten</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Einige Fehler überprüft</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Zum Schreibtisch wechseln</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Willkommen, das System wurde erfolgreich upgedatet</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Aktuelle Version:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>Aktualisierungen erfolgreich</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Ihr Computer wird gleich neustarten %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Ihr Computer wird gleich ausgeschalten %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>Das automatische Hochfahren ist fehlgeschlagen. Bitte versuchen sie manuell ihr Gerät wieder hochzufahren</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>Das automatische Hoerunterfahren ist fehlgeschlagen. Bitte versuchen sie manuell ihr Gerät auszuschalten.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Aktualisierungs-Protokoll ansehen</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Aktualisierungs-Protokoll einklappen</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>Aktualisierungs-Protokoll wurde zum Schreibtisch exportiert</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>Protokoll exportieren fehgeschlagen, bitte erneut versuchen</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Aktualisierung fehlgeschlagen</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>BackUp fehlgeschlagen</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>System-Sicherung konnte nicht durchgeführt werden. Falls Sie mit den System-Aktualisierungen fortfahren, können Sie nicht wieder zurück zum alten System.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Zu geringer Speicherplatz. Bitte schaffen Sie Platz auf ihrer Festplatte und versuchen es erneut.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Keine Verbindung zum BackUp-Server. Bitte checken und erneut versuchen.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Keine Verbindung zum Aktualisierungs-Server. Bitte prüfen und erneut versuchen.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Abhängigkeiten-Fehler</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG-Fehler</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Erneut BackUp erstellen</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Mit Aktualisieren fortfahren</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Neustart</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Runterfahren</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>zum Schreibtisch wechseln</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Aktualisieren vorbereiten…</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Während der Installation der Aktualisierungen nicht Herunterfahren oder Ausschalten erzwingen. Anderenfalls kann ihr System Schaden nehmen.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Aktualisierungs-Protokoll ansehen</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Aktualisierungs-Protokoll einklappen</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation>Aktualisierungs-Protokoll</translation>
    </message>
</context>
</TS>
